# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif
%{!?disttag: %global disttag .%{__distinit}%{__distvers}}

# Which libpcap package do we need to build against?
# --------------------------------------------------
%if 0%{!?libpcapreq:1}
# Red Hat Linux
%if "%{__distinit}" == "rhl"
%global libpcapreq libpcap
%endif
# Red Hat Enterprise Linux < 5
%if "%{__distinit}" == "rhel" && %{__distvers} < 5
%global libpcapreq libpcap
%endif
# Red Hat Enterprise Linux 5 onwards
%if "%{__distinit}" == "rhel" && %{__distvers} >= 5
%global libpcapreq libpcap-devel
%endif
# Fedora Core 1-5
%if "%{__distinit}" == "fc" && %{__distvers} < 6
%global libpcapreq libpcap
%endif
# Fedora Core 6 onwards
%if "%{__distinit}" == "fc" && %{__distvers} >= 6
%global libpcapreq libpcap-devel
%endif
%endif

# EAP-TLS requires openssl 0.9.7 onwards, so can't be used with RHL-7/8
%if "%{disttag}" == ".rhl7" || "%{disttag}" == ".rhl8"
%global enable_eaptls 0
%else
%global enable_eaptls 1
%endif

# This macro only defined by default around Fedora 18 time
%{!?_tmpfilesdir:%global _tmpfilesdir %{_prefix}/lib/tmpfiles.d}

# Do a hardened build where possible
%global _hardened_build 1

# Do a systemd-enabled build from F-15, EL-7
%global use_systemd %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -gt 14 ")" -o "(" "%{__distinit}" == "rhel" -a %{__distvers} -gt 6 ")" ] && echo 1 || echo 0)

Summary: The PPP (Point-to-Point Protocol) daemon
Name: ppp
Version: 2.4.5
Release: 34.0%{disttag}
License: BSD and LGPLv2+ and GPLv2+ and Public Domain
Group: System Environment/Daemons
Url: http://ppp.samba.org/ppp/
Source0: ftp://ftp.samba.org/pub/ppp/ppp-%{version}.tar.gz
Source1: ppp-2.3.5-pamd.conf
Source2: ppp.logrotate
Source3: ppp-tmpfs.conf
Patch0: ppp-2.4.5-make.patch
Patch1: ppp-2.3.6-sample.patch
Patch2: ppp-2.4.2-libutil.patch
Patch3: ppp-2.4.1-varargs.patch
Patch4: ppp-2.4.5-lib64.patch
Patch7: ppp-2.4.2-pie.patch
Patch8: ppp-2.4.5-fix.patch
Patch9: ppp-2.4.5-fix64.patch
Patch11: ppp-2.4.2-change_resolv_conf.patch
Patch13: ppp-2.4.5-no_strip.patch
Patch17: ppp-2.4.5-pppoatm-make.patch
Patch19: ppp-2.4.5-local.patch
Patch20: ppp-2.4.3-ipv6-accept-remote.patch
Patch22: ppp-2.4.4-cbcp.patch
Patch23: ppp-2.4.2-dontwriteetc.patch
Patch24: ppp-2.4.4-fd_leak.patch
Patch25: ppp-2.4.5-var_run_ppp.patch
Patch26: ppp-2.4.5-manpg.patch
Patch27: ppp-2.4.5-eaptls-mppe-0.99.patch
Patch28: ppp-2.4.5-ppp_resolv.patch
Patch29: ppp-2.4.5-man.patch
Patch30: ppp-2.4.5-eth.patch
Patch31: ppp-2.4.5-lock.patch
Patch32: ppp-2.4.5-l2tp-multilink.patch
Patch33: ppp-2.4.5-radius-config.patch
Patch34: ppp-2.4.5-crypt.patch
Patch35: ppp-2.4.5-hardened.patch
Patch36: 0001-pppd-Eliminate-potential-integer-overflow-in-option-.patch

# Non-Fedora patches:
Patch100: mppe_lower_mtu.diff
Patch101: ppp-2.4.2-ifname.diff
Patch102: ppp-2.4.3-atm_backend.patch
Patch103: ppp-2.4.5-debuginfo.patch
Patch104: ppp-2.4.3-oldpam.patch
Patch105: ppp-2.4.3-bpf.patch
Patch106: ppp-2.4.2-pcap.patch
Patch107: ppp-2.4.3-cbcp_debug.patch
Patch108: ppp-2.4.5-pppol2tp.patch
Patch121: ppp-2.4.4-usepeerdns-var_run_ppp_resolv.conf.patch

# Keep RedHat spec file in SRPM for comparison
Source100: ppp.spec.redhat

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires: pam-devel, %{libpcapreq} >= 0.6.2
%if %{enable_eaptls}
BuildRequires: openssl-devel
%endif
Requires: glibc >= 2.0.6, /etc/pam.d/system-auth
# Need systemd-units for ownership of /usr/lib/tmpfiles.d directory
# ... and definition of _tmpfilesdir macro
%if %{use_systemd}
BuildRequires: systemd-units
Requires: systemd-units
%endif
Requires(pre): /usr/bin/getent
Requires(pre): /usr/sbin/groupadd

%description
The ppp package contains the PPP (Point-to-Point Protocol) daemon and
documentation for PPP support. The PPP protocol provides a method for
transmitting datagrams over serial point-to-point links. PPP is
usually used to dial in to an ISP (Internet Service Provider) or other
organization over a modem and phone line.

%package devel
Summary: Headers for ppp plugin development
Group: Development/Libraries

%description devel
This package contains the header files for building plugins for ppp.

%prep
%setup -q
%patch0 -p1 -b .make
%patch1 -p1 -b .sample
# patch 2 depends on the -lutil in patch 0
%patch2 -p1 -b .libutil
%patch3 -p1 -b .varargs
# patch 4 depends on the -lutil in patch 0
%patch4 -p1 -b .lib64
%patch7 -p1 -b .pie
%patch8 -p1 -b .fix
%patch9 -p1 -b .fix64

# This patch for the ppp support scripts requires the change_resolv_conf
# function, defined in the /etc/sysconfig/network-scripts/network-functions file
if grep -F change_resolv_conf /etc/sysconfig/network-scripts/network-functions &> /dev/null; then
%patch11 -p1 -b .change_resolv_conf
%patch28 -p1 -b .ppp_resolv
else
%patch121 -p1 -b .usepeerdns-var_run_ppp_resolv
fi

%patch13 -p1 -b .no_strip
%patch17 -p1 -b .atm-make
%patch19 -p1 -b .local
%patch20 -p1 -b .ipv6cp
%patch22 -p1 -b .cbcp
%patch23 -p1 -b .dontwriteetc
%patch24 -p1 -b .fd_leak
%patch25 -p1 -b .var_run_ppp
%patch26 -p1 -b .manpg
%if %{enable_eaptls}
%patch27 -p1 -b .eaptls
%endif
%patch29 -p1 -b .man
# fixes bz#682381 - hardcodes eth0
%patch30 -p1 -b .eth
# fixes bz#708260 - SELinux is preventing access on the file LCK..ttyUSB3
%patch31 -p1 -b .lock
%patch32 -p1 -b .l2tp-multilink
%patch33 -p1 -b .radius
%patch34 -p1 -b .crypt
%patch35 -p1 -b .hardened
%patch36 -p1 -b .cve-2014-3158

# ============================================================================
# The remaining patches are additional to those in the official Fedora package
# ============================================================================

# Support additional options mppe-lower-mtu (default) & nomppe-lower-mtu
%patch100 -p1 -b .mtu

# Arvin Schnell's ifname patch
# http://marc.theaimsgroup.com/?l=linux-ppp&m=109025160924399&w=2
%patch101 -p0 -b .ifname

# atm_backend_t definition missing from system headers in Fedora Core 2
if ! grep -F atm_backend_t %{_includedir}/linux/atm.h &> /dev/null; then
%patch102 -p1 -b .atm_backend
fi

# pppd and pppoe-discovery installed without user write permission, prevents stripping
%patch103 -p1 -b .debuginfo

# Default PAM configuration file uses password-auth common config;
# revert to system-auth if password-auth is not available
cp -p %{SOURCE1} ppp.pam
if [ ! -f /etc/pam.d/password-auth ]; then
	perl -pi -e s/password-auth/system-auth/ ppp.pam
fi

# Default PAM configuration file uses "include" syntax introduced in Fedora Core 5
# This patch reverts to the older syntax for older distributions
if ! grep '^auth[[:space:]][[:space:]]*include' /etc/pam.d/config-util &> /dev/null; then
%patch104 -p0
fi

# libpcap < 0.8 has headers in different places
if [ ! -f %{_includedir}/pcap-bpf.h ]; then
%patch105 -p1 -b .bpf
fi

# Fix inbound/outbound filter processing using internal functions for old libpcap versions
if [ -f %{_includedir}/pcap-int.h ]; then
%patch106 -p1 -b .pcap
fi

# Don't debug trace calls to cbcp_open unless the debug flag is set
%patch107 -p1 -b .cbcp_debug

# Add definition of struct pppol2tpv3_addr in include/linux/if_pppol2tp.h,
# needed for kernels >= 2.6.35
%patch108 -p1 -b .pppol2tp

# Red Hat 7.x has SIOCSIFNAME defined in <linux/sockios.h> but not in <bits/ioctls.h>,
# which is included by <sys/ioctl.h> from pppd/sys-linux.c
# This symbol is needed for the interface name-changing patch, so here's a kludge...
if ! grep SIOCSIFNAME %{_includedir}/bits/ioctls.h &> /dev/null; then
  [ -f %{_includedir}/linux/sockios.h ] &&
    grep SIOCSIFNAME %{_includedir}/linux/sockios.h >> pppd/patchlevel.h
fi

# Clean up cruft left after patching etc.
rm -f \
	scripts/{ppp-on-[rs]sh,secure-card}.local \
	scripts/*change_resolv_conf \
	scripts/*usepeerdns-var_run_ppp_resolv \
	scripts/*.ppp_resolv \
	sample/*.sample

# Allow for build in directory with setgid permission bit set
chmod 755 sample scripts scripts/chatchat

%build
RPM_OPT_FLAGS="%{optflags} -fPIC -Wall"
[ -d /usr/kerberos/include ] && export CPPFLAGS="-I/usr/kerberos/include"
%configure
make

%install
rm -rf %{buildroot}
export INSTROOT=%{buildroot}
make install install-etcppp INSTALL="install -p"

chmod -R a+rX scripts
find scripts -type f | xargs chmod a-x
chmod 0755 %{buildroot}%{_libdir}/pppd/%{version}/*.so
mkdir -p %{buildroot}%{_sysconfdir}/pam.d
install -p -m 644 ppp.pam %{buildroot}%{_sysconfdir}/pam.d/ppp

# Places for state, lock and log files
mkdir -p %{buildroot}%{_localstatedir}/log/ppp
mkdir -p %{buildroot}%{_localstatedir}/run/ppp
mkdir -p %{buildroot}%{_localstatedir}/lock/ppp

# Re-create /var/run/ppp in case /var/run is on tmpfs (#656671)
%if %{use_systemd}
install -d -m 755 %{buildroot}%{_tmpfilesdir}
install -p -m 644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/ppp.conf
%endif

# Logrotate script
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/ppp

%clean
rm -rf %{buildroot}

%pre
getent group dip &>/dev/null || groupadd -r -g 40 dip &>/dev/null || :

%post
mkdir -p %{_localstatedir}/lock/ppp &>/dev/null || :

%files
%{_sbindir}/chat
%{_sbindir}/pppd
%{_sbindir}/pppdump
%{_sbindir}/pppoe-discovery
%{_sbindir}/pppstats
%{_mandir}/man8/chat.8*
%{_mandir}/man8/pppd.8*
%{_mandir}/man8/pppdump.8*
%{_mandir}/man8/pppd-radattr.8*
%{_mandir}/man8/pppd-radius.8*
%{_mandir}/man8/pppoe-discovery.8*
%{_mandir}/man8/pppstats.8*
%{_libdir}/pppd/
%dir %{_sysconfdir}/ppp/
%ghost %dir %{_localstatedir}/lock/ppp/
%dir %{_localstatedir}/run/ppp/
%dir %{_sysconfdir}/logrotate.d/
%if %{use_systemd}
%{_tmpfilesdir}/ppp.conf
%endif
%attr(700,root,root) %dir %{_localstatedir}/log/ppp/
%if %{enable_eaptls}
%config(noreplace) %{_sysconfdir}/ppp/eaptls-client
%config(noreplace) %{_sysconfdir}/ppp/eaptls-server
%endif
%config(noreplace) %{_sysconfdir}/ppp/chap-secrets
%config(noreplace) %{_sysconfdir}/ppp/options
%config(noreplace) %{_sysconfdir}/ppp/pap-secrets
%config(noreplace) %{_sysconfdir}/pam.d/ppp
%config(noreplace) %{_sysconfdir}/logrotate.d/ppp
%doc FAQ README README.cbcp README.linux README.MPPE README.MSCHAP80
%doc README.MSCHAP81 README.pwfd README.pppoe scripts sample README.eap-tls

%files devel
%{_includedir}/pppd
%doc PLUGINS

%changelog
* Sun Sep 14 2014 Paul Howarth <paul@city-fan.org> 2.4.5-34.0
- fix for CVE-2014-3158
- drop %%defattr, redundant since rpm 4.4

* Thu Aug  1 2013 Paul Howarth <paul@city-fan.org> 2.4.5-33.0
- fix post installation scriptlet to ignore failure

* Mon Jul 29 2013 Paul Howarth <paul@city-fan.org> 2.4.5-32.0
- don't ship /var/lock/ppp in rpm payload and create it in %%post instead
  (#980100)
- use %%{_tmpfilesdir} macro rather than hard-coding the location
- enable hardened build
- fix bogus dates in changelog

* Thu Jul  4 2013 Paul Howarth <paul@city-fan.org> 2.4.5-31.0
- fix possible NULL pointer dereferencing

* Wed May 29 2013 Paul Howarth <paul@city-fan.org> 2.4.5-30.0
- make radius plugin config parser less strict (#906913)

* Wed Mar 20 2013 Paul Howarth <paul@city-fan.org> 2.4.5-29.0
- drop hard dependency on logrotate
- add creation of dip system group (GID = 40)

* Tue Nov 13 2012 Paul Howarth <paul@city-fan.org> 2.4.5-25.0
- rebuild again

* Sat Jul 21 2012 Paul Howarth <paul@city-fan.org> 2.4.5-23.0
- rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> 2.4.5-22.1
- move the tmpfiles.d config from %%{_sysconfdir} to %%{_prefix}/lib

* Tue May 29 2012 Paul Howarth <paul@city-fan.org> 2.4.5-22.0
- fix ppp-2.4.5-eaptls-mppe-0.99 patch (#817011)
- fix ppp-2.4.5-pppol2tp.patch for IPv6 support, needed for Rawhide

* Mon May 21 2012 Paul Howarth <paul@city-fan.org> 2.4.5-21.0
- fix support for multilink channels in pppol2tp plugin (#817013)

* Thu May 17 2012 Paul Howarth <paul@city-fan.org> 2.4.5-20.0
- fix compilation of pppd without USE_EAPTLS (#771340)

* Fri Jul 29 2011 Paul Howarth <paul@city-fan.org> 2.4.5-18.1
- fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun  2 2011 Paul Howarth <paul@city-fan.org> 2.4.5-18.0
- fixes #682381 - hardcodes eth0
- fixes #708260 - SELinux is preventing access on the file LCK..ttyUSB3

* Tue Apr  5 2011 Paul Howarth <paul@city-fan.org> 2.4.5-17.0
- man page fixes (#664282, #664868)
- nobody else likes macros for commands

* Thu Dec  2 2010 Paul Howarth <paul@city-fan.org> 2.4.5-15.0
- corrected tmpfiles.d conf

* Wed Dec  1 2010 Paul Howarth <paul@city-fan.org> 2.4.5-14.0
- add /etc/tmpfiles.d/ppp.conf to create /var/run/ppp at boot time to support
  operation with tmpfs on /var/run in Fedora 15 onwards (#656671)
- replaced /var with %%{_localstatedir} and /etc with %%{_sysconfdir}

* Tue Nov 16 2010 Paul Howarth <paul@city-fan.org> 2.4.5-13.0
- fix #565294 - SELinux is preventing /sbin/consoletype access to a leaked
  packet_socket fd

* Tue Oct  5 2010 Paul Howarth <paul@city-fan.org> 2.4.5-12.0
- sync with ppp-2.4.5-12 in Rawhide
- updated to latest eaptls upstream
- fix #637513 - Missing README.eap-tls
- fix #637886 - EAP-TLS not working with enabled PPP Multilink Framing option

* Thu Aug  5 2010 Paul Howarth <paul@city-fan.org> 2.4.5-11.0
- sync with ppp-2.4.5-11 in Rawhide
- instroot patch merged into lib64 patch
- maintain timestamps on installed files where possible

* Fri Jul 23 2010 Paul Howarth <paul@city-fan.org> 2.4.5-10.0
- fix missing line in example script ip-up.local.add (#613717)
- install pppol2tp plugins (#572174)
- remove /usr/kerberos/include from eaptls patch
- reinstate -I/usr/kerberos/include where needed for older distributions
- add definition of struct pppol2tpv3_addr in include/linux/if_pppol2tp.h,
  needed for kernels >= 2.6.35

* Wed Jun 16 2010 Paul Howarth <paul@city-fan.org> 2.4.5-9.0
- include eap-tls patch

* Thu May 20 2010 Paul Howarth <paul@city-fan.org> 2.4.5-8.1
- fix dist tag for RHEL-6 Beta

* Wed Apr  7 2010 Paul Howarth <paul@city-fan.org> 2.4.5-8.0
- added pppoe-discovery(8)
- update debuginfo patch

* Mon Mar 15 2010 Paul Howarth <paul@city-fan.org> 2.4.5-7.0
- merged Fedora usepeerdns-var_run_ppp_resolv patch into
  change_resolv_conf patch; still need local version of this patch for old
  distributions for which we don't apply the change_resolv_conf patch

* Mon Feb 15 2010 Paul Howarth <paul@city-fan.org> 2.4.5-6.0
- move pppd2.tdb from /var/run to /var/run/ppp (#560014)

* Mon Feb  8 2010 Paul Howarth <paul@city-fan.org> 2.4.5-5.0
- plug leaked file descriptors using close-on-exec where possible

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> 2.4.5-2.0
- update to 2.4.5
  - under Linux, pppd supports having no peer IP address (using device routes)
  - better support for 3G modems
  - PPP over L2TP plugin included
  - a new 'enable-session' option has been added (see pppd man page)
  - several bugs have been fixed
- updated patches:
  fix, pppoatm-make, no_strip, make, lib64, local, fix64, debuginfo
- dropped patches:
  bogus_dns_addr, closelog, new_speeds, pppoatm-mtu, response_len

* Wed Nov 18 2009 Paul Howarth <paul@city-fan.org> 2.4.4-14.1
- use perl rather than sed to fix up PAM config for spec compatibility all the
  way back to RHL-7

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> 2.4.4-14.0
- fixed #524575 (no_strip patch modifies backup files for previous patches)
- rawhide dist tag no longer needs special-casing

* Thu Sep 17 2009 Paul Howarth <paul@city-fan.org> 2.4.4-13.0
- use password-auth common PAM configuration instead of system-auth

* Sun Aug  2 2009 Paul Howarth <paul@city-fan.org> 2.4.4-12.0
- rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  9 2009 Paul Howarth <paul@city-fan.org> 2.4.4-11.0
- rebuild for all releases

* Fri Mar  6 2009 - Jiri Skala <jskala@redhat.com> 2.4.4-11
- fixed #488764 - package upgrade should not replace configuration files

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> 2.4.4-10.0
- update to SLES-compatible dist tag macros

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.4-10
- rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Dec 11 2008 Jiri Skala <jskala@redhat.com> 2.4.4-9.0
- fixed #467004 PPP sometimes gets incorrect DNS servers for mobile broadband
  connections

* Thu Sep  4 2008 Paul Howarth <paul@city-fan.org> 2.4.4-8.0
- tweak dist tag macros to work on current Rawhide with three-part releasenum

* Thu Aug 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> 2.4.4-8
- fix license tag
- re-diff patches to remove fuzz

* Tue May 13 2008 Martin Nagy <mnagy@redhat.com> 2.4.4-7.0
- add new speeds, patch by Jason Vas Dias (#446132)

* Thu Mar 27 2008 Paul Howarth <paul@city-fan.org> 2.4.4-6.0
- rebuild for older distrbutions
- remove old patch for #217076, now duplicated by official patch
- update ppp.spec.redhat in SRPM to 2.4.4-6

* Thu Mar 06 2008 Martin Nagy <mnagy@redhat.com> 2.4.4-6
- call closelog earlier (#222295)
- fix ChapMS2 (#217076)
- moving header files to new -devel package (#203542)

* Tue Mar  4 2008 Paul Howarth <paul@city-fan.org> 2.4.4-5.0
- put logs into /var/log/ppp (#118837)

* Tue Feb 19 2008 Paul Howarth <paul@city-fan.org> 2.4.4-4.0
- rebuild with gcc 4.3.0 for Fedora 9
- update ppp.spec.redhat in SRPM to 2.4.4-4

* Mon Nov 12 2007 Paul Howarth <paul@city-fan.org> 2.4.4-3.1
- update ppp.spec.redhat in SRPM to 2.4.4-3
  (this package was not affected by #241753)
- clarify license as GPL version 2 or later

* Mon Jun 25 2007 Paul Howarth <paul@city-fan.org> 2.4.4-2.1
- update ppp.spec.redhat in SRPM to 2.4.4-2

* Tue Mar 20 2007 Paul Howarth <paul@city-fan.org> 2.4.4-1.3
- add RHEL5 and Fedora 7 build support

* Wed Nov 29 2006 Paul Howarth <paul@city-fan.org> 2.4.4-1.2
- fix dist tag for development builds
- add patch to fix connection to paranoid PPTP server using mschapv2 (#217076)

* Fri Sep  8 2006 Paul Howarth <paul@city-fan.org> 2.4.4-1.1
- add dist tag
- add URL
- define %%{__id_u} for builds on non-Red Hat-based distributions
- use Fedora standard buildroot
- vary libpcap buildreq based on distribution/release
- remove versioned libpcap dependency
- remove buildroot unconditionally in %%install
- got rid of a few cosmetic rpmlint warnings
- add patches:
  * patch to support mppe_lower_mtu/nomppe_lower_mtu options
  * Arvin Schnell's ifname patch
    (http://marc.theaimsgroup.com/?l=linux-ppp&m=109025160924399&w=2)
  * define atm_backend_t if the system headers don't (needed on FC2)
  * extract debug symbols from pppd and pppoe-discovery
  * use old-style PAM configs on older distributions
  * look for libpcap headers in different places on older distributions
  * fix inbound/outbound filter processing using internal functions for
    old libpcap versions
  * don't debug trace calls to cbcp_open unless the debug flag is set
  * make sure SIOCSIFNAME is defined (needed for ifname patch on RHL7)
- clean patch cruft more carefully (don't delete ipv6 sample scripts)
- cosmetic spec file tidying

* Wed Jul 19 2006 Thomas Woerner <twoerner@redhat.com> 2.4.4-1
- new version 2.4.4 with lots of fixes
- fixed resolv.conf docs (#165072)
  Thanks to Matt Domsch for the initial patch
- enabled CBCP (#199278)

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.4.3-6.2.2
- rebuild

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 2.4.3-6.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 2.4.3-6.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Sat Nov 12 2005 Florian La Roche <laroche@redhat.com>
- rebuild

* Fri Nov  4 2005 David Woodhouse <dwmw2@redhat.com> 2.4.3-5
- Implement ipv6cp-accept-remote option

* Fri Oct  7 2005 Tomas Mraz <tmraz@redhat.com> 2.4.3-4
- use include instead of pam_stack in pam config

* Sun Jul 31 2005 Florian La Roche <laroche@redhat.com>
- rebuild for libpcap of the day

* Tue Jul 19 2005 Thomas Woerner <twoerner@redhat.com> 2.4.3-2.1
- additional patch for the scripts, thanks to Sammy (#163621)

* Tue Jul 19 2005 Thomas Woerner <twoerner@redhat.com> 2.4.3-2
- dropped all executable bits in scripts directory to prevent rpm requiring
  programs used in there

* Mon Jul 18 2005 Thomas Woerner <twoerner@redhat.com> 2.4.3-1
- new version 2.4.3
  - updated patches: make, lib64, dontwriteetc, fix, fix64, no_strip,
    radiusplugin
  - dropped patches: bpf, signal, pcap, pppoatm, pkgcheck

* Tue Nov  2 2004 Thomas Woerner <twoerner@redhat.com> 2.4.2-7
- fixed out of bounds memory access, possible DOS

* Thu Oct  7 2004 David Woodhouse <dwmw2@redhat.com> 2.4.2-6.3
- Fix use of 'demand' without explicit MTU/MRU with pppoatm

* Tue Oct  5 2004 David Woodhouse <dwmw2@redhat.com> 2.4.2-6.2
- Link pppoatm plugin against libresolv.
- Revert to linux-atm headers without the workaround for #127098

* Mon Oct  4 2004 David Woodhouse <dwmw2@redhat.com> 2.4.2-6.1
- Include atmsap.h for pppoatm plugin.

* Mon Oct  4 2004 David Woodhouse <dwmw2@redhat.com> 2.4.2-6
- Add pppoatm plugin (#131555)

* Thu Sep 16 2004 Thomas Woerner <twoerner@redhat.com> 2.4.2-5.1
- fixed subscript out of range (#132677)

* Wed Sep 15 2004 Thomas Woerner <twoerner@redhat.com> 2.4.2-5
- example scripts are using change_resolv_conf to modify /etc/resolv.conf
  (#132482)
- require new libpcap library (>= 0.8.3-6) with a fix for inbound/outbound
  filter processing
- not using internal libpcap structures anymore, fixes inbound/outbound
  filter processing (#128053)

* Fri Aug  6 2004 Thomas Woerner <twoerner@redhat.com> 2.4.2-4
- fixed signal handling (#29171)

* Mon Jun 21 2004 Thomas Woerner <twoerner@redhat.com> 2.4.2-3.1
- fixed compiler warnings
- fixed 64bit problem with ms-chap (#125501)
- enabled pie again

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon May 24 2004 David Woodhouse <dwmw2@redhat.com> 2.4.2-2.3
- Enable IPv6 support. Disable PIE to avoid bogus Provides:

* Fri May 14 2004 Thomas Woerner <twoerner@redhat.com> 2.4.2-2.2
- compiled pppd and chat PIE

* Thu May 13 2004 Thomas Woerner <twoerner@redhat.com> 2.4.2-2.1
- added 'missingok' to ppp.logrotate (#122911)

* Fri May 07 2004 Nils Philippsen <nphilipp@redhat.com> 2.4.2-2
- don't write to /etc (#118837)

* Wed Mar 10 2004 Nalin Dahyabhai <nalin@redhat.com> 2.4.2-1
- update to 2.4.2

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Sep  5 2003 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-15
- rebuild

* Fri Sep  5 2003 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-14
- apply the patch from -11

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Jun  3 2003 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-12
- rebuild

* Tue Jun  3 2003 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-11
- check for libcrypt in the right directory at compile-time

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Thu Dec 12 2002 Elliot Lee <sopwith@redhat.com> 2.4.1-9
- Fix build failure by rebuilding

* Tue Nov 19 2002 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-8
- rebuild
- set x86_64 to use varargs the way s390 does

* Mon Jul 22 2002 Florian La Roche <Florian.LaRoche@redhat.de>
- add patch for varargs problem for s390/s390x from Phil Knirsch

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Fri May 17 2002 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-4
- rebuild in new environment

* Wed Feb 27 2002 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-3
- revert cbcp patch, it's wrong (#55367)

* Thu Aug  9 2001 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-2
- add buildprereq on pam-devel (#49559)
- add patch to respond to CBCP LCP requests (#15738)
- enable cbcp support at build-time
- change the Copyright: tag to a License: tag

* Wed May 23 2001 Nalin Dahyabhai <nalin@redhat.com> 2.4.1-1
- update to 2.4.1

* Fri Dec  1 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Thu Nov  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 2.4.0

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jun  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- move man pages to %%{_mandir}

* Thu Jun  1 2000 Nalin Dahyabhai <nalin@redhat.com>
- change perms using defattr
- modify PAM setup to use system-auth

* Sun Mar 26 2000 Florian La Roche <Florian.La Roche@redhat.com>
- change to root:root perms

* Mon Mar 06 2000 Nalin Dahyabhai <nalin@redhat.com>
- reaper bugs verified as fixed
- check pam_open_session result code (bug #9966)

* Mon Feb 07 2000 Nalin Dahyabhai <nalin@redhat.com>
- take a shot at the wrong reaper bugs (#8153, #5290)

* Thu Feb 03 2000 Nalin Dahyabhai <nalin@redhat.com>
- free ride through the build system (release 2)

* Tue Jan 18 2000 Nalin Dahyabhai <nalin@redhat.com>
- Update to 2.3.11

* Sat Nov 06 1999 Michael K. Johnson <johnsonm@redhat.com>
- Better fix for both problems

* Fri Nov 05 1999 Michael K. Johnson <johnsonm@redhat.com>
- fix for double-dial problem
- fix for requiring a controlling terminal problem

* Sun Sep 19 1999 Preston Brown <pbrown@redhat.com>
- 2.3.10 bugfix release

* Fri Aug 13 1999 Michael K. Johnson <johnsonm@redhat.com>
- New version 2.3.9 required for kernel 2.3.13 and will be required
  for new initscripts.  auth patch removed; 2.3.9 does the same thing
  more readably than the previous patch.

* Thu Jun 24 1999 Cristian Gafton <gafton@redhat.com>
- add pppdump

* Fri Apr 09 1999 Cristian Gafton <gafton@redhat.com>
- force pppd use the glibc's logwtmp instead of implementing its own

* Thu Apr 01 1999 Preston Brown <pbrown@redhat.com>
- version 2.3.7 bugfix release

* Tue Mar 23 1999 Cristian Gafton <gafton@redhat.com>
- version 2.3.6

* Mon Mar 22 1999 Michael Johnson <johnsonm@redhat.com>
- auth patch

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 3)

* Thu Jan 07 1999 Cristian Gafton <gafton@redhat.com>
- build for glibc 2.1

* Fri Jun  5 1998 Jeff Johnson <jbj@redhat.com>
- updated to 2.3.5.

* Tue May 19 1998 Prospector System <bugs@redhat.com>
- translations modified for de

* Fri May  8 1998 Jakub Jelinek <jj@ultra.linux.cz>
- make it run with kernels 2.1.100 and above.

* Fri Apr 24 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Wed Mar 18 1998 Cristian Gafton <gafton@redhat.com>
- requires glibc 2.0.6 or later

* Wed Mar 18 1998 Michael K. Johnson <johnsonm@redhat.com>
- updated PAM patch to not turn off wtmp/utmp/syslog logging.

* Wed Jan  7 1998 Cristian Gafton <gafton@redhat.com>
- added the /etc/pam.d config file
- updated PAM patch to include session support

* Tue Jan  6 1998 Cristian Gafton <gafton@redhat.com>
- updated to ppp-2.3.3, build against glibc-2.0.6 - previous patches not
  required any more.
- added buildroot
- fixed the PAM support, which was really, completely broken and against any
  standards (session support is still not here... :-( )
- we build against running kernel and pray that it will work
- added a samples patch; updated glibc patch

* Thu Dec 18 1997 Erik Troan <ewt@redhat.com>
- added a patch to use our own route.h, rather then glibc's (which has
  alignment problems on Alpha's) -- I only applied this patch on the Alpha,
  though it should be safe everywhere

* Fri Oct 10 1997 Erik Troan <ewt@redhat.com>
- turned off the execute bit for scripts in /usr/doc

* Fri Jul 18 1997 Erik Troan <ewt@redhat.com>
- built against glibc

* Tue Mar 25 1997 Erik Troan <ewt@redhat.com>
- Integrated new patch from David Mosberger
- Improved description

